/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.keycloak.storage.user;

import org.keycloak.models.RealmModel;
import org.keycloak.models.RoleModel;

/**
 * This is an optional capability interface that is intended to be implemented by any
 * {@link org.keycloak.storage.UserStorageProvider UserStorageProvider} that supports bulk operations.
 *
 * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
 * @version $Revision: 1 $
 */
public interface UserBulkUpdateProvider {
    
    /**
     * Grants the given role to all users from particular realm. The role has to
     * belong to the realm. 
     * @param realm Realm
     * @param role Role to be granted
     */
    void grantToAllUsers(RealmModel realm, RoleModel role);
}
